@@ -13,12 +13,16 @@ rectFill<-function(x1,y1,x2,y2,fg=par("fg"),bg=par("bg"),xinc=NA,yinc=NA,
  if(length(pch.col) < nrect) pch.col<-rep(pch.col,nrect)
  for(frect in 1:nrect) {
   rect(x1[frect],y1[frect],x2[frect],y2[frect],col=bg[frect],border=fg[frect])
-  xpos<-seq(x1[frect]+xinc[frect]/2,x2[frect]-xinc[frect]/2,by=xinc[frect])
-  lenxpos<-length(xpos)
-  ypos<-seq(y1[frect]+yinc[frect]/2,y2[frect]-yinc[frect]/2,by=yinc[frect])
-  lenypos<-length(ypos)
-  xpos<-rep(xpos,each=lenypos)
-  ypos<-rep(ypos,lenxpos)
-  points(xpos,ypos,pch=pch[frect],cex=pch.cex[frect],col=pch.col[frect],...)
+  if(yinc[frect] > 0) {
+   xpos<-seq(x1[frect]+xinc[frect]/2,x2[frect]+xinc[frect]/2,by=xinc[frect])
+   lenxpos<-length(xpos)
+   ypos<-seq(y1[frect]+yinc[frect]/2,y2[frect]+yinc[frect],by=yinc[frect])
+   lenypos<-length(ypos)
+   xpos<-rep(xpos,each=lenypos)
+   ypos<-rep(ypos,lenxpos)
+   clip(x1[frect],x2[frect],y1[frect],y2[frect])
+   points(xpos,ypos,pch=pch[frect],cex=pch.cex[frect],col=pch.col[frect],...)
+  }
  }
+ do.call(clip,as.list(par("usr")))
 }
